==> haskell-extra-1.4.3-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-extra/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: extra
version: 1.4.3
id: extra-1.4.3-ab419342055a04bda9f8a7a264d348c1
key: extra_IqmEYVRG4As1WuHksSqfuY
license: BSD3
copyright: Neil Mitchell 2014-2016
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/extra#readme
synopsis: Extra functions I use.
description:
    A library of extra functions for the standard Haskell libraries. Most functions are simple additions, filling out missing functionality. A few functions are available in later versions of GHC, but this package makes them available back to GHC 7.2.
    .
    The module "Extra" documents all functions provided by this library. Modules such as "Data.List.Extra" provide extra functions over "Data.List" and also reexport "Data.List". Users are recommended to replace "Data.List" imports with "Data.List.Extra" if they need the extra functionality.
category: Development
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
exposed-modules:
    Extra Control.Concurrent.Extra Control.Exception.Extra
    Control.Monad.Extra Data.Either.Extra Data.IORef.Extra
    Data.List.Extra Data.Tuple.Extra Data.Version.Extra Numeric.Extra
    System.Directory.Extra System.Environment.Extra System.Info.Extra
    System.IO.Extra System.Process.Extra System.Time.Extra
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/extra-1.4.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/extra-1.4.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/extra-1.4.3
hs-libraries: HSextra-1.4.3-IqmEYVRG4As1WuHksSqfuY
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
haddock-interfaces: /usr/share/doc/haskell-extra/html/extra.haddock
haddock-html: /usr/share/doc/haskell-extra/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-extra-1.4.6-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-extra/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: extra
version: 1.4.6
id: extra-1.4.6-bd6c06cb9c31ba2a6069a7f244dac489
key: extra_KDFVPMm47sPKqkGH260vpK
license: BSD3
copyright: Neil Mitchell 2014-2016
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/extra#readme
synopsis: Extra functions I use.
description:
    A library of extra functions for the standard Haskell libraries. Most functions are simple additions, filling out missing functionality. A few functions are available in later versions of GHC, but this package makes them available back to GHC 7.2.
    .
    The module "Extra" documents all functions provided by this library. Modules such as "Data.List.Extra" provide extra functions over "Data.List" and also reexport "Data.List". Users are recommended to replace "Data.List" imports with "Data.List.Extra" if they need the extra functionality.
category: Development
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
exposed-modules:
    Extra Control.Concurrent.Extra Control.Exception.Extra
    Control.Monad.Extra Data.Either.Extra Data.IORef.Extra
    Data.List.Extra Data.Tuple.Extra Data.Version.Extra Numeric.Extra
    System.Directory.Extra System.Environment.Extra System.Info.Extra
    System.IO.Extra System.Process.Extra System.Time.Extra
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/extra-1.4.6
library-dirs: /usr/lib/ghc-7.10.3/site-local/extra-1.4.6
data-dir: /usr/share/arm-linux-ghc-7.10.3/extra-1.4.6
hs-libraries: HSextra-1.4.6-KDFVPMm47sPKqkGH260vpK
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
haddock-interfaces: /usr/share/doc/haskell-extra/html/extra.haddock
haddock-html: /usr/share/doc/haskell-extra/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
